@@ -6,9 +6,9 @@ Type annotations for personalize-runtime service literal definitions.
 Usage::
 
     ```python
-    from mypy_boto3_personalize_runtime.literals import ServiceName
+    from mypy_boto3_personalize_runtime.literals import PersonalizeRuntimeServiceName
 
-    data: ServiceName = "accessanalyzer"
+    data: PersonalizeRuntimeServiceName = "personalize-runtime"
     ```
 """
 import sys
@@ -19,9 +19,10 @@ else:
     from typing_extensions import Literal
 
 
-__all__ = ("ServiceName",)
+__all__ = ("PersonalizeRuntimeServiceName", "ServiceName", "ResourceServiceName")
 
 
+PersonalizeRuntimeServiceName = Literal["personalize-runtime"]
 ServiceName = Literal[
     "accessanalyzer",
     "account",
@@ -53,6 +54,7 @@ ServiceName = Literal[
     "backup",
     "backup-gateway",
     "batch",
+    "billingconductor",
     "braket",
     "budgets",
     "ce",
@@ -175,6 +177,7 @@ ServiceName = Literal[
     "kafka",
     "kafkaconnect",
     "kendra",
+    "keyspaces",
     "kinesis",
     "kinesis-video-archived-media",
     "kinesis-video-media",
@@ -323,3 +326,15 @@ ServiceName = Literal[
     "workspaces-web",
     "xray",
 ]
+ResourceServiceName = Literal[
+    "cloudformation",
+    "cloudwatch",
+    "dynamodb",
+    "ec2",
+    "glacier",
+    "iam",
+    "opsworks",
+    "s3",
+    "sns",
+    "sqs",
+]
