@@ -14,6 +14,8 @@ Usage::
 import sys
 from typing import Dict, List, Mapping, Sequence
 
+from typing_extensions import NotRequired
+
 if sys.version_info >= (3, 9):
     from typing import TypedDict
 else:
@@ -29,31 +31,17 @@ __all__ = (
     "ResponseMetadataTypeDef",
 )
 
-_RequiredGetPersonalizedRankingRequestRequestTypeDef = TypedDict(
-    "_RequiredGetPersonalizedRankingRequestRequestTypeDef",
+GetPersonalizedRankingRequestRequestTypeDef = TypedDict(
+    "GetPersonalizedRankingRequestRequestTypeDef",
     {
         "campaignArn": str,
         "inputList": Sequence[str],
         "userId": str,
+        "context": NotRequired[Mapping[str, str]],
+        "filterArn": NotRequired[str],
+        "filterValues": NotRequired[Mapping[str, str]],
     },
 )
-_OptionalGetPersonalizedRankingRequestRequestTypeDef = TypedDict(
-    "_OptionalGetPersonalizedRankingRequestRequestTypeDef",
-    {
-        "context": Mapping[str, str],
-        "filterArn": str,
-        "filterValues": Mapping[str, str],
-    },
-    total=False,
-)
-
-
-class GetPersonalizedRankingRequestRequestTypeDef(
-    _RequiredGetPersonalizedRankingRequestRequestTypeDef,
-    _OptionalGetPersonalizedRankingRequestRequestTypeDef,
-):
-    pass
-
 
 GetPersonalizedRankingResponseTypeDef = TypedDict(
     "GetPersonalizedRankingResponseTypeDef",
@@ -67,16 +55,15 @@ GetPersonalizedRankingResponseTypeDef = TypedDict(
 GetRecommendationsRequestRequestTypeDef = TypedDict(
     "GetRecommendationsRequestRequestTypeDef",
     {
-        "campaignArn": str,
-        "itemId": str,
-        "userId": str,
-        "numResults": int,
-        "context": Mapping[str, str],
-        "filterArn": str,
-        "filterValues": Mapping[str, str],
-        "recommenderArn": str,
+        "campaignArn": NotRequired[str],
+        "itemId": NotRequired[str],
+        "userId": NotRequired[str],
+        "numResults": NotRequired[int],
+        "context": NotRequired[Mapping[str, str]],
+        "filterArn": NotRequired[str],
+        "filterValues": NotRequired[Mapping[str, str]],
+        "recommenderArn": NotRequired[str],
     },
-    total=False,
 )
 
 GetRecommendationsResponseTypeDef = TypedDict(
@@ -91,10 +78,9 @@ GetRecommendationsResponseTypeDef = TypedDict(
 PredictedItemTypeDef = TypedDict(
     "PredictedItemTypeDef",
     {
-        "itemId": str,
-        "score": float,
+        "itemId": NotRequired[str],
+        "score": NotRequired[float],
     },
-    total=False,
 )
 
 ResponseMetadataTypeDef = TypedDict(
